@@ -5,7 +5,7 @@ from .symmetrization_heuristic import SymmetrizationHeuristic
 from .symmetrized_word_aligner import SymmetrizedWordAligner
 from .symmetrized_word_alignment_model import SymmetrizedWordAlignmentModel
 from .symmetrized_word_alignment_model_trainer import SymmetrizedWordAlignmentModelTrainer
-from .trainer import ProgressStatus, Trainer, TrainStats
+from .trainer import Trainer, TrainStats
 from .word_aligner import WordAligner
 from .word_alignment_matrix import WordAlignmentMatrix
 from .word_alignment_model import WordAlignmentModel
@@ -14,7 +14,6 @@ __all__ = [
     "HmmWordAlignmentModel",
     "Ibm1WordAlignmentModel",
     "Ibm2WordAlignmentModel",
-    "ProgressStatus",
     "SymmetrizationHeuristic",
     "SymmetrizedWordAligner",
     "SymmetrizedWordAlignmentModel",
